Page 153 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 153

Home

    When the nations that occupied ancient Palestine
    became corrupted beyond redemption, the Israelites were
    sent to overcome them. This is made plain in

    sent to

    Not for thy righteousness, or for the uprightness of
    thine heart, dost thou go to possess their land: but for
    the wickedness of these nations the Lord thy God doth
    drive them out before thee,. . .

    later,

    when

    the

    had

    been

    corrupted to the point that they were burning their
    children to death as human sacrifices to Moleck, the ten

    northern tribes were invaded and deported by Assyria.
    To this day, these ten dispersed tribes have never been

    found.

    The first attempt to circumvent the Divine order of
    sovereign and independent nations was frustrated by a
    division of languages, as recorded in Genesis 11:7, "Go
    to, let us go down, and there confound their language,
    that they may not understand one another's speech." This
    time those who wish to replace sovereign nations with a
    one world government have assembled with their
    interpreters. This time they have built a tower on the East
    River in New York. This time they plan to drive the
    concept of loyalty to God, family, and country off the
    earth.

    laid at the founding conference of the United Nations in
    San Francisco in 1945. The man who was Secretary

    148

    The Secret Side of History

    made plain in

    Deuteronomy 9:5:

    Centuries

    Israelites

    The foundation for this modern Tower of Babel was